#! /bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/updatedb - updatedb configuration
#
# Creation   :  2007-02-28 schlotze
# Last update:  $Id: updatedb.sh 29733 2012-02-02 10:15:14Z hbfl $
#
# Copyright (c) 2007-2009 Sebastian Scholze <webmaster(at)schlotze(dot)de
# Copyright (c) 2009-2012 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

. /var/install/include/eislib

updated=`date '+%Y-%m-%d %H:%M:%S'`
pgmname=$0
# set path names:
updatedb_conf_path=/etc/config.d
crontab_path=/var/cron/etc/root
# set file names
crontab_file=$crontab_path/updatedb
# user-edited configuration files:
updatedb_file=$updatedb_conf_path/updatedb
# updatedb update:
updater=/usr/bin/updatedb
# Error log:
error_file=/tmp/updatedb.errors
# programs
prunepaths=''
#
# load user-edited configuration files:
. $updatedb_file
chmod 600 $updatedb_file

# ---------------------------------------------------------------------------
# create crontab file for updatedb
# ---------------------------------------------------------------------------
create_crontab_file ()
{
    # check for cron directory
    if [ ! -d $crontab_path ]
    then
        mkdir -p $crontab_path
    fi
}

# ---------------------------------------------------------------------------
# delete cron job
# ---------------------------------------------------------------------------
delete_crontab_file ()
{
    echo "deleting automatic update of locatedb:!..."
    # check for crontab file
    if [ -f $crontab_file ]
    then
        # delete existing file
        rm -f $crontab_file

        # update crontab file
        /var/install/config.d/cron >/dev/null 2>/dev/null
    fi
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

case "$1" in
    # generate configuration
    run)
        sh /usr/bin/updatedb &
    ;;
    uninstall)
        if [ -f "$crontab_file" ]
        then
            delete_crontab_file
        fi
    ;;
    *)
        # prune paths
        idx=1
        while [ $idx -le $UPDATEDB_PRUNEPATH_N ]
        do
            eval active='${UPDATEDB_PRUNEPATH_'${idx}_'ACTIVE}'

            if [ ${active} = yes ]
            then
                eval prunepath='$UPDATEDB_PRUNEPATH_'$idx
                prunepaths="$prunepath $prunepaths"
            fi
            idx=`/usr/bin/expr $idx + 1`
        done

        sed -i "s|^: \${PRUNEPATHS=\".*$|: \${PRUNEPATHS=\"$prunepaths\"}|" /usr/bin/updatedb
        # remove old crontab file:
        if [ -f "$crontab_file" ]
        then
            delete_crontab_file
        fi
        # set cronjob for updatedb update
        if [ "$UPDATEDB_CRON_USE" = "yes" ]
        then
            if [ ! -f "$crontab_file" ]
            then
                create_crontab_file
            fi
            echo "-- setting automatic updatedb update ..."
            {
                echo "# Do not edit this file, edit $updatedb_file"
                echo "# Creation date: ${EISDATE} ${EISTIME}"
            } >$crontab_file

            if [ "$UPDATEDB_SUPPRESS_CRON_MAIL" = "yes" ]
            then
                echo "$UPDATEDB_CRON_TIMES $updater 1>/dev/null" >> $crontab_file
            else
                echo "$UPDATEDB_CRON_TIMES $updater" >> $crontab_file
            fi
        fi

        # update fcrontab file
        echo "Updating crontabs ..."
        sh /var/install/config.d/cron
        sh /etc/init.d/cron restart
        echo "updatedb configuration is activated."
    ;;
esac

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
